```{mermaid}
:alt: Data process graph
:caption: Data process graph. Nodes in progress are highlighted.
flowchart TD
 node1["compare_theory"]
 node2["data\rois.dvc"]
 node3["data\sources.dvc"]
 node4["fill"]
 node5["find_contours"]
 node6["find_tracks"]
 node7["find_unobstructed"]
 node8["preview_binarized"]
 node9["preview_filled"]
 node10["preview_gray"]
 node11["data\examples.dvc"]
 node12["data\samples.dvc"]
 style node1 fill:#fff87b
 style node6 fill:#fff87b
 style node7 fill:#fff87b
 node2-->node8
 node3-->node4
 node3-->node5
 node3-->node8
 node3-->node9
 node3-->node10
 node4-->node9
 node5-->node4
 node5-->node7
 node6-->node1
 node7-->node6
```
